@@ -14,8 +14,8 @@ titration <- function(aquaenv,                # an object of type aquaenv: minim
                       k_boh3=NULL,            # a fixed K_BOH3 can be specified
                       k_hso4=NULL,            # a fixed K_HSO4 can be specified
                       k_hf=NULL,              # a fixed K_HF can be specified
-                      k1k2="lueker",          # either "lueker" (default, Lueker2000) or "roy" (Roy1993a) or for K\_CO2 and K\_HCO3
-                      khf="dickson")          # either "dickson" (default, Dickson1979a) or "perez" (Perez1987a, calculated with seacarb) for K\_HF}
+                      k1k2="lueker",          # either "lueker" (default, Lueker2000) or "roy" (Roy1993a) or for K_CO2 and K_HCO3
+                      khf="dickson")          # either "dickson" (default, Dickson1979a) or "perez" (Perez1987a, calculated with seacarb) for K_HF}
   {
     concstep <- function(conc, oldmass, newmass)
       {
@@ -109,8 +109,8 @@ TAfit <- function(ae,                         # an object of type aquaenv: minim
                   k_hf=NULL,                  # a fixed K_HF can be specified
                   nlscontrol=nls.lm.control(),# nls.lm.control() can be specified
                   verbose=FALSE,              # verbose mode: show the traject of the fitting in a plot
-                  k1k2="roy",                 # either "roy" (default, Roy1993a) or "lueker" (Lueker2000, calculated with seacarb) for K\_CO2 and K\_HCO3
-                  khf="dickson",              # either "dickson" (default, Dickson1979a) or "perez" (Perez1987a, calculated with seacarb) for K\_HF}
+                  k1k2="roy",                 # either "roy" (default, Roy1993a) or "lueker" (Lueker2000, calculated with seacarb) for K_CO2 and K_HCO3
+                  khf="dickson",              # either "dickson" (default, Dickson1979a) or "perez" (Perez1987a, calculated with seacarb) for K_HF}
                   datxbegin=0,                # at what x value (amount of titrant added) does the supplied curve start? (i.e. is the complete curve supplied or just a part?)
                   SumCO2Zero=FALSE)           # should SumCO2==0 ?
   {
